@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 The Software Heritage developers
+# Copyright (C) 2017-2021 The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,9 +6,9 @@
 from typing import Any, Dict, List, Tuple
 
 from rest_framework.permissions import AllowAny
+from rest_framework.views import APIView
 
 from swh.deposit import utils
-from swh.deposit.api.common import AuthenticatedAPIView
 
 from ...config import METADATA_TYPE, APIConfig
 from ...models import Deposit, DepositRequest
@@ -60,14 +60,16 @@ class DepositReadMixin:
         return (aggregated_metadata, raw_metadata)
 
 
-class APIPrivateView(APIConfig, AuthenticatedAPIView):
+class APIPrivateView(APIConfig, APIView):
     """Mixin intended as private api (so no authentication) based API view
        (for the private ones).
 
     """
 
-    authentication_classes = ()
-    permission_classes = (AllowAny,)
+    def __init__(self):
+        super().__init__()
+        self.authentication_classes = ()
+        self.permission_classes = (AllowAny,)
 
     def checks(self, req, collection_name, deposit=None):
         """Override default checks implementation to allow empty collection.
